@@ -5,4 +5,6 @@ from . import mlp_mixer
 from . import conv_mixer
 from . import segformer
 from . import masked_autoencoder
+from . import swin_transformer
 from .model_registry import list_models, load_model
+from .helper import load_trained_params, save_trained_params, download_checkpoint_params
