@@ -1,11 +1,15 @@
 import jax.numpy as jnp
-
 import flax.linen as nn
-from typing import Optional, Union, Sequence, Iterable
 
 from ..layers import DepthwiseConv2D, SeparableDepthwiseConv2D
 from ..activations import hardswish
 
+from typing import Optional, Union, Sequence, Iterable
+import logging
+
+logging.basicConfig(format="%(levelname)s:%(message)s", level=logging.INFO)
+
+
 __all__ = ["MPViT", "MPViT_Tiny", "MPViT_XSmall", "MPViT_Small", "MPViT_Base"]
 
 
@@ -334,9 +338,24 @@ class MultiPathTransformerBlock(nn.Module):
 
 
 class MPViT(nn.Module):
+    """
+    MPViT Module
+
+    Attributes:
+        mlp_ratio (int): Multiplier for hidden dimension in transformer MLP block. Default is 2.
+        channels_list (list or tuple): Number of channels for each stage.
+        num_layers_list (list or tuple): Number of layers for each stage.
+        att_drop (float): Dropout value for attention Default is 0.2.
+        proj_drop (float): Dropout value for attention projection. Default is 0.2.
+        attach_head (bool): Whether to attach classification head. Default is True.
+        num_classes (int): Number of classification classes. Only works if attach_head is True. Default is 1000.
+        deterministic (bool): Optional argument, if True, network becomes deterministic and dropout is not applied.
+
+    """
+
     mlp_ratio: int = 2
-    channels_list: Iterable = (64, 96, 176, 216)
-    num_layers_list: Iterable = (1, 2, 4, 1)
+    channels_list: Iterable[int] = (64, 96, 176, 216)
+    num_layers_list: Iterable[int] = (1, 2, 4, 1)
     att_drop: float = 0.2
     proj_drop: float = 0.2
     attach_head: bool = True
@@ -372,7 +391,19 @@ class MPViT(nn.Module):
         return mptb
 
 
-def MPViT_Tiny(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def MPViT_Tiny(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs,
+):
+    if pretrained:
+        logging.info(
+            "Pretrained model for MPViT tiny isn't available. Loading un-trained model instead"
+        )
+
     return MPViT(
         mlp_ratio=2,
         channels_list=(64, 96, 176, 216),
@@ -385,7 +416,19 @@ def MPViT_Tiny(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
     )
 
 
-def MPViT_XSmall(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def MPViT_XSmall(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs,
+):
+    if pretrained:
+        logging.info(
+            "Pretrained model for MPViT XSmall isn't available. Loading un-trained model instead"
+        )
+
     return MPViT(
         mlp_ratio=4,
         channels_list=(64, 128, 192, 256),
@@ -398,7 +441,19 @@ def MPViT_XSmall(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
     )
 
 
-def MPViT_Small(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def MPViT_Small(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs,
+):
+    if pretrained:
+        logging.info(
+            "Pretrained model for MPViT Small isn't available. Loading un-trained model instead"
+        )
+
     return MPViT(
         mlp_ratio=4,
         channels_list=(64, 128, 216, 288),
@@ -411,7 +466,19 @@ def MPViT_Small(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
     )
 
 
-def MPViT_Base(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def MPViT_Base(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs,
+):
+    if pretrained:
+        logging.info(
+            "Pretrained model for MPViT Base isn't available. Loading un-trained model instead"
+        )
+
     return MPViT(
         mlp_ratio=4,
         channels_list=(128, 224, 368, 480),
