@@ -1,10 +1,13 @@
 import jax.numpy as jnp
-
 import flax.linen as nn
-from typing import Optional
 
 from ..layers import SqueezeAndExcitation, DropPath, TransformerMLP
 
+from typing import Optional
+import logging
+
+logging.basicConfig(format="%(levelname)s:%(message)s", level=logging.INFO)
+
 __all__ = [
     "PatchConvNet",
     "PatchConvNet_S60",
@@ -138,6 +141,20 @@ class AttentionPoolingBlock(nn.Module):
 
 
 class PatchConvNet(nn.Module):
+    """
+    PatchConvNet Module
+
+    Attributes:
+        depth (int): Depth for PatchConvNet. Default is 20.
+        dim (int): Embedding dimension. Default is 768.
+        dropout (float): Dropout value. Default is 0.5.
+        mlp_ratio (int): Multiplier for hidden dimension in transformer MLP block. Default is 4.
+        attach_head (bool): Whether to attach classification head. Default is True.
+        num_classes (int): Number of classification classes. Only works if attach_head is True. Default is 1000.
+        deterministic (bool): Optional argument, if True, network becomes deterministic and dropout is not applied.
+
+    """
+
     depth: int = 20
     dim: int = 768
     dropout: float = 0.5
@@ -174,7 +191,14 @@ class PatchConvNet(nn.Module):
         return x
 
 
-def PatchConvNet_S60(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def PatchConvNet_S60(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs
+):
     model = PatchConvNet(
         depth=60,
         dim=384,
@@ -187,7 +211,14 @@ def PatchConvNet_S60(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
     return model
 
 
-def PatchConvNet_S120(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def PatchConvNet_S120(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs
+):
     model = PatchConvNet(
         depth=120,
         dim=384,
@@ -200,7 +231,14 @@ def PatchConvNet_S120(attach_head=True, num_classes=1000, dropout=0.1, **kwargs)
     return model
 
 
-def PatchConvNet_B60(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def PatchConvNet_B60(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs
+):
     model = PatchConvNet(
         depth=60,
         dim=768,
@@ -213,7 +251,14 @@ def PatchConvNet_B60(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
     return model
 
 
-def PatchConvNet_B120(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def PatchConvNet_B120(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs
+):
     model = PatchConvNet(
         depth=120,
         dim=768,
@@ -226,7 +271,14 @@ def PatchConvNet_B120(attach_head=True, num_classes=1000, dropout=0.1, **kwargs)
     return model
 
 
-def PatchConvNet_L60(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def PatchConvNet_L60(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs
+):
     model = PatchConvNet(
         depth=60,
         dim=1024,
@@ -239,7 +291,14 @@ def PatchConvNet_L60(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
     return model
 
 
-def PatchConvNet_L120(attach_head=True, num_classes=1000, dropout=0.1, **kwargs):
+def PatchConvNet_L120(
+    attach_head=True,
+    num_classes=1000,
+    dropout=0.1,
+    pretrained=False,
+    download_dir=None,
+    **kwargs
+):
     model = PatchConvNet(
         depth=120,
         dim=1024,
